#
# spec file for package libprelude
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{!?python_sitearch3: %global python_sitearch3 %(python3 -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}
%{!?ruby_sitearch: %global ruby_sitearch %(ruby -rrbconfig -e 'puts RbConfig::CONFIG["sitearchdir"] ')}
%{!?luaver: %global luaver %(lua -e "print(string.sub(_VERSION, 5))")}
%{!?luapkgdir: %global luapkgdir %{_libdir}/lua/%{luaver}}
%define sover 28
%define sover_cpp 12
Name:           libprelude
Version:        5.2.0
Release:        2.21
Summary:        Secure Connections between all Sensors and the Prelude Manager
License:        LGPL-2.1-only AND LGPL-2.1-or-later
Group:          Productivity/Networking/Security
URL:            https://www.prelude-siem.org
Source0:        https://www.prelude-siem.org/pkg/src/%{version}/%{name}-%{version}.tar.gz
Source1:        https://www.prelude-siem.org/pkg/src/%{version}/%{name}-%{version}.tar.gz.sig
Source2:        https://www.prelude-siem.org/attachments/download/233/RPM-GPG-KEY-Prelude-IDS#/%{name}.keyring
# Wrong test
Patch0:         libprelude-fix_prelude_tests_timer.patch
# pthread_atfork was automatically linked before but not anymore
Patch1:         libprelude-fix_pthread_atfork.patch
# Fix time comparaison
Patch2:         libprelude-fix_timegm.patch
# Wrong FSF address
Patch3:         libprelude-fsf-address.patch
# Fix 64 bit portability issues
Patch5:         libprelude-fix_64bit_portability_issues.patch
Patch7:         libprelude-fix_gtkdoc_1.32.patch
Patch8:         libprelude-5.2.0-ruby2.7.patch
BuildRequires:  gcc-c++
BuildRequires:  gtk-doc
BuildRequires:  libgpg-error-devel
BuildRequires:  lua-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  ruby
BuildRequires:  ruby-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnutls)
BuildRequires:  pkgconfig(libpcre)

%description
Libprelude is a library that guarantees secure connections between all sensors
and the Prelude Manager. Libprelude provides an Application Programming Interface
(API) for the communication with Prelude sub-systems, it supplies the necessary
functionality for generating and emitting IDMEF events with Prelude and automates
the saving and re-transmission of data in times of temporary interruption of one
of the components of the system.

%package -n %{name}%{sover}
Summary:        Prelude Libraries
Group:          System/Libraries

%description -n %{name}%{sover}
Libprelude is a library that guarantees secure connections between all sensors
and the Prelude Manager. Libprelude provides an Application Programming Interface
(API) for the communication with Prelude sub-systems, it supplies the necessary
functionality for generating and emitting IDMEF events with Prelude and automates
the saving and re-transmission of data in times of temporary interruption of one
of the components of the system.

%package -n %{name}cpp%{sover_cpp}
Summary:        Prelude Libraries
Group:          System/Libraries

%description -n %{name}cpp%{sover_cpp}
Libprelude is a library that guarantees secure connections between all sensors
and the Prelude Manager. Libprelude provides an Application Programming Interface
(API) for the communication with Prelude sub-systems, it supplies the necessary
functionality for generating and emitting IDMEF events with Prelude and automates
the saving and re-transmission of data in times of temporary interruption of one
of the components of the system.

%package -n prelude-tools
Summary:        Tools for libprelude
Group:          Development/Libraries/C and C++
Requires:       %{name}%{sover} = %{version}

%description -n prelude-tools
Libprelude is a library that guarantees secure connections between all sensors
and the Prelude Manager. Libprelude provides an Application Programming Interface
(API) for the communication with Prelude sub-systems, it supplies the necessary
functionality for generating and emitting IDMEF events with Prelude and automates
the saving and re-transmission of data in times of temporary interruption of one
of the components of the system.

%package devel
Summary:        Development files for libprelude
Group:          Development/Libraries/C and C++
Requires:       libgcrypt-devel
Requires:       libgpg-error-devel
Requires:       libprelude%{sover} = %{version}
Requires:       libpreludecpp%{sover_cpp} = %{version}
Requires:       pkgconfig(gnutls)
Requires:       pkgconfig(libpcre)

%description devel
Libprelude is a library that guarantees secure connections between all sensors
and the Prelude Manager. Libprelude provides an Application Programming Interface
(API) for the communication with Prelude sub-systems, it supplies the necessary
functionality for generating and emitting IDMEF events with Prelude and automates
the saving and re-transmission of data in times of temporary interruption of one
of the components of the system.

%package devel-bindings
Summary:        Development files for libprelude
Group:          Development/Libraries/C and C++
Requires:       %{name}-devel = %{version}
Requires:       lua-devel
Requires:       python3-devel
Requires:       ruby-devel
Requires:       swig

%description devel-bindings
Libprelude is a library that guarantees secure connections between all sensors
and the Prelude Manager. Libprelude provides an Application Programming Interface
(API) for the communication with Prelude sub-systems, it supplies the necessary
functionality for generating and emitting IDMEF events with Prelude and automates
the saving and re-transmission of data in times of temporary interruption of one
of the components of the system.

%package -n perl-%{name}
Summary:        Perl bindings for libprelude
Group:          Development/Languages/Perl
BuildRequires:  perl
Requires:       libprelude%{sover} = %{version}
Requires:       perl = %{perl_version}

%description -n perl-%{name}
Perl bindings for libprelude generated by SWIG.

%package -n python3-%{name}
Summary:        Python 3 bindings for libprelude
Group:          Development/Languages/Python
Requires:       libprelude%{sover} = %{version}

%description -n python3-%{name}
Python 3 bindings for libprelude generated by SWIG.

%package -n ruby-%{name}
Summary:        Ruby bindings for libprelude
Group:          Development/Languages/Ruby
Requires:       libprelude%{sover} = %{version}
Requires:       ruby

%description -n ruby-%{name}
Ruby bindings for libprelude generated by SWIG.

%package -n lua-%{name}
Summary:        Lua bindings for libprelude
# FIXME: use correct group or remove it, see "https://en.opensuse.org/openSUSE:Package_group_guidelines"
Group:          Development/Languages/Lua
Requires:       libprelude%{sover} = %{version}
Requires:       lua

%description -n lua-%{name}
Lua bindings for libprelude generated by SWIG.

%package doc
Summary:        Libprelude documentation
Group:          System/Libraries

%description doc
Libprelude documentation files.

%prep
%setup -q
%patch0
%patch1
%patch2
%patch3
%patch5
%patch7
# ruby 2.7
%if 0%{?suse_version} > 1500
%patch8 -p1
%endif

%build
%configure    --disable-static \
              --with-html-dir=%{_defaultdocdir}/%{name}-%{version}/html \
              --with-perl-installdirs=vendor \
              --without-python2 \
              --enable-gtk-doc \
  	      gl_cv_func_printf_directive_n=yes \
  	      gl_cv_func_printf_infinite_long_double=yes

%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%perl_process_packlist
%perl_gen_filelist
mkdir -p %{buildroot}/${_localstatedir}/spool/prelude
mv %{buildroot}/%{_datadir}/libprelude %{buildroot}/%{_datadir}/libprelude%{sover}

%post -n libprelude%{sover} -p /sbin/ldconfig
%post -n libpreludecpp%{sover_cpp} -p /sbin/ldconfig
%postun -n libprelude%{sover} -p /sbin/ldconfig
%postun -n libpreludecpp%{sover_cpp} -p /sbin/ldconfig

%files -n %{name}%{sover}
%license COPYING
%{_libdir}/libprelude.so.%{sover}*
%dir %{_localstatedir}/spool/prelude

%files -n prelude-tools
%license COPYING
%{_bindir}/prelude-adduser
%{_bindir}/prelude-admin
%{_mandir}/man1/prelude-admin.1%{?ext_man}
%dir %{_sysconfdir}/prelude
%dir %{_sysconfdir}/prelude/default
%dir %{_sysconfdir}/prelude/profile
%config(noreplace) %{_sysconfdir}/prelude/default/client.conf
%config(noreplace) %{_sysconfdir}/prelude/default/global.conf
%config(noreplace) %{_sysconfdir}/prelude/default/idmef-client.conf
%config(noreplace) %{_sysconfdir}/prelude/default/tls.conf

%files -n %{name}cpp%{sover_cpp}
%license COPYING
%{_libdir}/libpreludecpp.so.%{sover_cpp}*

%files devel
%license COPYING
%{_bindir}/libprelude-config
%{_includedir}/libprelude
%{_libdir}/libprelude.so
%{_libdir}/libpreludecpp.so
%{_libdir}/pkgconfig/libprelude.pc
%{_datadir}/aclocal/libprelude.m4

%files devel-bindings
%license COPYING
%dir %{_datadir}/libprelude%{sover}/
%dir %{_datadir}/libprelude%{sover}/swig
%{_datadir}/libprelude%{sover}/swig/libpreludecpp.i
%dir %{_datadir}/libprelude%{sover}/swig/lua/
%{_datadir}/libprelude%{sover}/swig/lua/libpreludecpp-lua.i
%dir %{_datadir}/libprelude%{sover}/swig/perl/
%{_datadir}/libprelude%{sover}/swig/perl/libpreludecpp-perl.i
%dir %{_datadir}/libprelude%{sover}/swig/python/
%{_datadir}/libprelude%{sover}/swig/python/libpreludecpp-python.i
%dir %{_datadir}/libprelude%{sover}/swig/ruby/
%{_datadir}/libprelude%{sover}/swig/ruby/libpreludecpp-ruby.i

%files -n perl-%{name} -f %{name}.files
%license COPYING
%exclude %{_bindir}/libprelude-config
%exclude %{_bindir}/prelude-adduser
%exclude %{_bindir}/prelude-admin
%exclude %{_mandir}/man1/prelude-admin.1.gz

%files -n python3-%{name}
%license COPYING
%{python_sitearch3}/*

%files -n ruby-%{name}
%{ruby_sitearch}/Prelude.so

%files -n lua-%{name}
%license COPYING
%{luapkgdir}/prelude.so

%files doc
%license COPYING LICENSE.README
%doc %{_docdir}/%{name}-%{version}
%doc AUTHORS ChangeLog README NEWS HACKING.README

%changelog
* Thu Nov 11 2021 Steve Kowalik <steven.kowalik@suse.com>
- Remove python-devel Requires on devel-bindings package
- Drop unrequired and broken Requires on python in python3-libprelude.
* Sun Oct 25 2020 Andreas Stieger <andreas.stieger@gmx.de>
- libprelude 5.2.0:
  * license switched to LGPL
  * Add Python 3.7/3.8 suppo
  * Update to SWIG 4.0.1
  * Implement prelude_msg_clone()
  * Update libprelude-error for GAWK 5.0
  * Various IDMEF criteria improvements
- drop upstreamed patches:
  * libprelude-linking.patch
  * libprelude-fix_awk_error.patch
  * libprelude-fix_py38.patch
- add libprelude-5.2.0-ruby2.7.patch on Tumbleweed to fix build
  with ruby 2.7
- package license with every package
- add upstream signing key and verify source signature
* Fri Oct 25 2019 thomas.andrejak@gmail.com
  Bump version 5.1.1
  - Update internal dependencies (SWIG, ...)
  - Better support for unicode
  - Fully support Python3
  - Better features for debugging
  - Fix various bugs
- CPP Soname bump 8 to 12
- Add patchs:
  - libprelude-fix_awk_error.patch
  - Support of recents awk versions
  - libprelude-fix_gtkdoc_1.32.patch
  - Support of recents gtkdoc versions
  - libprelude-fix_py38.patch
  - Add support for Python3.8
- Remove patch:
  - libprelude-disable_gnulib_test_lock.patch
  - Fixed upstream
- Remove Python 2 support
  - Python 2 will be removed step by step in all Linux distributions
* Fri Mar  1 2019 thomas.andrejak@gmail.com
  Bump version 5.0.0
- Remove patchs included in new version
  - libprelude-fix_compatibility_gnutls_3_6.patch
  - libprelude-gtk-doc.patch
- Add new patch for 64bit portability
  - libprelude-fix_64bit_portability_issues.patch
* Wed Oct  4 2017 thomas.andrejak@gmail.com
- Bump to libprelude 4.0.0
- Add patchs:
  - libprelude-disable_gnulib_test_lock.patch: Known bug on gnulib side and
    will be fixed
  - libprelude-fix_prelude_tests_timer.patch: Wrong test
  - libprelude-fix_pthread_atfork.patch: pthread_atfork was automatically
    linked before but not anymore
  - libprelude-fix_timegm.patch: Fix time comparaison
  - libprelude-fsf-address.patch: Wrong FSF address
  - libprelude-gtk-doc.patch: gtk-doc removed gtkdoc-tmpl so gtk-doc.make and
    gtk-doc.m4 need to be updated
  - libprelude-linking.patch: Correctly link for Perl bindings
  - libprelude-fix_compatibility_gnutls_3_6.patch: Fix compatibility with
    GnuTLS 3.6
- Remove libgcrypt-devel from BuildRequires since upstream totally move to
  gnutls
- Rename python-prelude to python2-prelude
* Tue Apr 25 2017 thomas.andrejak@gmail.com
- Rename %%soname to %%sover to better reflect its use
* Sun Nov 27 2016 thomas.andrejak@gmail.com
- Update to 3.1.0 (Prelude 3.1.0 released on 14 Sept 2016)
- Remove unnecessary patches
  - libprelude-fsf-address.patch
  - libprelude-rpm-opt-flags.patch
  - libprelude-ruby-include-path.patch
  - libprelude-python-swig.patch
  - libprelude-ruby-swig.patch
- Use a lib directory with soname
- Spec-Cleaner
* Mon May  2 2016 thomas.andrejak@gmail.com
- Update to 3.0.0 (Prelude 3.0.0 released on 22 Apr 2016)
- Add few patches to build with all bindings and reduce rpmlint
  notices :
  * libprelude-fsf-address.patch
  * Correct the Free Software Foundation address
  * libprelude-python-swig.patch
  * Regenerate swig file to compile with Python 3.4 and newer
  * libprelude-ruby-swig.patch
  * Temporary fix http://bugs.ruby-lang.org/issues/11962
  * libprelude-ruby-include-path.patch
  * Fix ruby include path. Instead, we can not turn ruby
    binding on
  * libprelude-rpm-opt-flags.patch
  * Fix libprelude do not load global CFLAGS for
    libprelude-error
- We now build all bindings, adding :
  * lua-libprelude
  * python3-libprelude
  * ruby-libprelude
- Create a new package with only tools files because packages
  started with "lib" do not have to come with tools. Name of the
  package : prelude-tools
- Precise license :
  * Prelude is GPL-2.0+
  * libmissing is LGPL-2.1+
  * libmissing/test is GPL-3.0+
- Remove support for older SUSE than 12 since libprelude do not
  compile on it
* Sat Nov 14 2015 mardnh@gmx.de
- update to 1.2.6
- removed patches (all fixed upstream)
  * opensuse12_compile.patch
  * libprelude-1.0.1-fixgnulib.patch
  * libprelude-1.0.0-gcc46.patch
  * libprelude-sles12sp2.patch
  * libprelude-fixlibgnutls3.0.5.patch
  * libprelude-ruby1.9.patch
  * libprelude-fsf-address.patch
  * libprelude-swig-3.0.patch
- disabled lua and ruby bindings for now
* Mon Jan 26 2015 dimstar@opensuse.org
- Add libprelude-swig-3.0.patch: Fix build with swig 3.0.
* Tue Jul  9 2013 schwab@suse.de
- Override broken configure checks
* Tue Apr  9 2013 Greg.Freemyer@gmail.com
- change license to GPLv3.0+ due to libmissing being incorporated (bnc#814000)
- remove requirement for libgnutls-devel as done previously (see below)
* Fri Apr  5 2013 pth@suse.de
- Add a definition of perl_gen_filelist for SLE11 to the spec file.
* Thu Mar 28 2013 Greg.Freemyer@gmail.com
- Update to v1.0.1
- Add these patches
  * libprelude-1.0.1-fixgnulib.patch
  * libprelude-1.0.0-gcc46.patch
  * libprelude-fixlibgnutls3.0.5.patch
  * libprelude-ruby1.9.patch
  * libprelude-fsf-address.patch
  * libprelude-sles12sp2.patch
- Create new subpackages
  * libprelude-doc
  * ruby-libprelude
  * perl-libprelude
  * python-libprelude
* Mon Dec  5 2011 aldemir.akpinar@airties.com
- Added a simple patch file to fix the compile error for OpenSUSE 12.1
* Mon Nov  7 2011 lars@linux-schulserver.de
- build require libgcrypt-devel
- use gnutls-devel instead of libgnutls-devel to build on old
  distributions (package provides both names)
* Wed Oct 20 2010 jooop.boonen@opensuse.org
- fixed to used pkg-config in stead of libgnutls-config
  so it builds with >= gnutls-2.7.0
* Sat Jul 24 2010 bitshuffler@opensuse.org
- Initial package
